"""
Module contains event targets enum.
"""

from enum import Enum


class EventTargets(Enum):
    """
    Enum for event target columns
    """

    eventId = "event_id"  #: event id
    accountId = "account_id"  #: account id
    createTime = "create_time"  #: event create time
    endTime = "end_time"  #: event end time
    externalId = "external_id"  #: external id
    handlerId = "handler_id"  #: handler id
    source = "source"  #: source
    streamId = "stream_id"  #: source
    topMatch = "top_match"  #: top match object
    matchResult = "match_result"  #: object that contains match result
    faceDetections = "face_detections"  #: list of all face detections and corresponding sample ids
    bodyDetections = "body_detections"  #: list of all body detections and corresponding sample ids
    faceId = "face_id"  #: face id that created from event
    attachResult = "attach_result"  #: list of lina list id with the face
    gender = "gender"  #: gender
    age = "age"  #: age
    emotion = "emotion"  #: emotion
    ethnicGroup = "ethnic_group"  #: ethnic group
    tags = "tags"  #: tags
    userData = "user_data"  #: user data
    location = "location"  #: event location
    mask = "mask"  #: mask
    trackId = "track_id"  #: track id
    liveness = "liveness"  #: liveness
    bodyBasicAttributes = "body_basic_attributes"  #: body basic attributes
    upperBody = "upper_body"  #: body upper attributes
    lowerBody = "lower_body"  #: body lower attributes
    accessories = "accessories"  #: body accessories
    meta = "meta"  #: event meta


class EventLocations(Enum):
    """
    Enum for event location columns
    """

    city = "city"
    area = "area"
    district = "district"
    street = "street"
    houseNumber = "house_number"
    geoPosition = "geo_position"


class MatchType(Enum):
    """
    Enum for event match type object
    """

    face = 0
    event = 1
