"""
Common regexps

Attributes:
    REQUEST_ID_REGEXP: compiled regexp  for request id string
"""
import re

from vlutils.regexps import UUID_REGEXP_STR

VALID_DB_STRING_PATTERN = "^[^\\x00]*$"  # reject NUL character
REQUEST_ID_REGEXP = re.compile(rf"^[0-9]{{10}},{UUID_REGEXP_STR}\Z", re.I)
SPECIAL_SYMBOLS_REGEXP = re.compile(r"^[a-zA-Z0-9_\-,]+$", re.I)
TRACK_ID_REGEXP = re.compile(r"^[a-zA-Z0-9_\-]{1,36}$", re.I)
IMAGE_STORE_REGEXP = re.compile(r"^/\d+/buckets/[a-z0-9-_]{1,255}/images/" + UUID_REGEXP_STR + r"\Z", re.I)

##################### Url regexp #####################

# pylint: disable=invalid-name
_ul = "\u00a1-\uffff"  # unicode letters range (must not be a raw string)
_symbol = r"[a-z" + _ul + r"0-9-_]"
# IP patterns
_ipv4Re = r"(?:25[0-5]|2[0-4]\d|[0-1]?\d?\d)(?:\.(?:25[0-5]|2[0-4]\d|[0-1]?\d?\d)){3}"
_ipv6Re = r"\[[0-9a-f:\.]+\]"  # (simple regex, validated later)

# Host patterns
_hostnameRe = rf"[a-z{_ul}0-9](?:{_symbol}{{0,61}}[a-z{_ul}0-9])?"
# _hostname_re r'[a-z'_ul'0-9](?:'_symbol'{0,61}[a-z' + _ul + r'0-9])?'
# Max length for domain name labels is 63 characters per RFC 1034 sec. 3.1
_domainRe = rf"(?:\.(?!-){_symbol}{{1,63}}(?<!-))*"
_tldRe = (
    r"\."  # dot
    r"(?!-)"  # can't start with a dash
    rf"(?:[a-z{_ul}-]{{2,63}}"  # domain label
    r"|xn--[a-z0-9]{1,59})"  # or punycode label
    r"(?<!-)"  # can't end with a dash
    r"\.?"  # may have a trailing dot
)
_hostRe = f"({_hostnameRe}{_domainRe}{_tldRe}|localhost|{_hostnameRe})"

_absoluteUrl = (
    r"(?:(?:http|ftp)s?://)"  # scheme
    r"(?:[^\s:@/]+(?::[^\s:@/]*)?@)?"  # user:pass authentication
    rf"(?:{_ipv4Re}|{_ipv6Re}|{_hostRe})"  # host
    r"(?::\d{2,5})?"  # port
    r"(?:[/?#][^\s]*)?"  # resource path
)

_relativeUrl = r"(?:\.?[/?#][^\s]*)?"  # resource path

_urlRegexpStr = rf"^(?:(?:)|(?:{_absoluteUrl})|(?:{_relativeUrl}))\Z"

# pylint: enable=invalid-name
URL_REGEXP = re.compile(_urlRegexpStr, re.I)
